@@ -95,18 +95,24 @@ desc <- function(cmd = NULL, file = NULL, text = NULL, package = NULL) {
 #' \preformatted{  x$set(foo = "bar")
 #'   x$del("foo")}
 #'
-#' \code{$get_or_fail} is similar to \code{$get}, but throws an error
-#' if a field does not exist, except of silently returning
-#' \code{NA_character}.
+#' \code{$get_field} is similar to \code{$get}, but it queries a single
+#' field, it returns an unnamed vector if found, and returns the
+#' specified \code{default} value if not. By default it throws an error
+#' if the field is not found.
 #'
 #' The complete API reference:
 #' \preformatted{  description$get(keys)
-#'   description$get_or_fail(keys)
+#'   description$get_field(key, default, trim_ws = TRUE)
 #'   description$set(...)
 #'   description$fields()
 #'   description$has_fields(keys)
 #'   description$del(keys)}
 #' \describe{
+#'   \item{key:}{A character string (length one), the key to query.}
+#'   \item{default:}{If specified and \code{key} is missing, this value
+#'     is returned. If not specified, an error is thrown.}
+#'   \item{trim_ws:}{Whether to trim leading  and trailing whitespace
+#'     from the returned value.}
 #'   \item{keys:}{A character vector of keys to query, check or delete.}
 #'   \item{...:}{This must be either two unnamed arguments, the key and
 #'     and the value to set; or an arbitrary number of named arguments,
@@ -122,8 +128,8 @@ desc <- function(cmd = NULL, file = NULL, text = NULL, package = NULL) {
 #' via \code{$reformat_fields()} and also reordering them via
 #' \code{$reorder_fields()}. The format of the various fields is
 #' opinionated and you might like it or not. Note that \code{desc} only
-#' reformats fields that it updates, and only on demand, so if your
-#' formatting preferences differ, you can still manually edit 
+#' re-formats fields that it updates, and only on demand, so if your
+#' formatting preferences differ, you can still manually edit
 #' \code{DESCRIPTION} and \code{desc} will respect your edits.
 #'
 #' \preformatted{  description$str(by_field = FALSE, normalize = TRUE,
@@ -146,7 +152,7 @@ desc <- function(cmd = NULL, file = NULL, text = NULL, package = NULL) {
 #' @section Writing it to file:
 #' The \code{$write} method writes the description to a file.
 #' By default it writes it to the file it was created from, if it was
-#' created from a file. Otherwise giving a file name is compulsary:
+#' created from a file. Otherwise giving a file name is compulsory:
 #' \preformatted{  x$write(file = "DESCRIPTION")}
 #'
 #' The \code{normalize} argument controls whether the fields are
@@ -276,7 +282,7 @@ desc <- function(cmd = NULL, file = NULL, text = NULL, package = NULL) {
 #'
 #' @section Authors:
 #' There is a specialized API for the \code{Authors@R} field,
-#' to add and remove authors, udpate their roles, change the maintainer,
+#' to add and remove authors, update their roles, change the maintainer,
 #' etc.
 #'
 #' The API:
@@ -396,6 +402,27 @@ desc <- function(cmd = NULL, file = NULL, text = NULL, package = NULL) {
 #'
 #' \code{$clear_remotes()} deletes all remotes.
 #'
+#' @section Built:
+#'
+#' The \sQuote{Built} field is used in binary packages to store information
+#' about when and how a binary package was built.
+#'
+#' \code{$get_built()} returns the built information as a list with fields
+#' \sQuote{R}, \sQuote{Platform}, \sQuote{Date}, \sQuote{OStype}. It throws an
+#' error if the package does not have a \sQuote{Built} field.
+#'
+#' @section Encodings:
+#' When creating a `description` object, `desc` observes the `Encoding`
+#' field, if present, and uses the specified encoding to parse the file.
+#' Internally, it converts all fields to UTF-8.
+#'
+#' When writing a `description` object to a file, `desc` uses the
+#' `Encoding` field (if present), and converts all fields to the specified
+#' encoding.
+#'
+#' We suggest that whenever you need to use non-ASCII characters in your
+#' package, you use the UTF-8 encoding, for maximum portability.
+#'
 #' @export
 #' @importFrom R6 R6Class
 #' @docType class
@@ -438,6 +465,10 @@ description <- R6Class("description",
     get = function(keys)
       idesc_get(self, private, keys),
 
+    get_field = function(key, default = stop("Field '", key, "' not found"),
+                         trim_ws = TRUE)
+      idesc_get_field(self, private, key, default, trim_ws),
+
     get_or_fail = function(keys)
       idesc_get_or_fail(self, private, keys),
 
@@ -594,12 +625,18 @@ description <- R6Class("description",
       idesc_del_remotes(self, private, pattern),
 
     clear_remotes = function()
-      idesc_clear_remotes(self, private)
+      idesc_clear_remotes(self, private),
+
+    ## -----------------------------------------------------------------
+    ## Built
+
+    get_built = function()
+      idesc_get_built(self, private)
   ),
 
   private = list(
     data = NULL,
-    path = "DESCRIPTION",
+    path = NULL,
     notws = character()                   # entries without trailing ws
   )
 )
@@ -673,7 +710,7 @@ idesc_create_file <- function(self, private, file) {
   } else {
     private$path <- normalizePath(file)
   }
-  
+
   tryCatch(
     lines <- readLines(file),
     error = function(e) stop("Cannot read ", file, ": ", e$message)
@@ -711,6 +748,13 @@ idesc_write <- function(self, private, file) {
   }
 
   mat <- idesc_as_matrix(private$data)
+  if ("Encoding" %in% colnames(mat)) {
+    encoding <- mat[, "Encoding"]
+    mat[] <- iconv(mat[], from = "UTF-8", to = encoding)
+    Encoding(mat) <- encoding
+  } else {
+    encoding <- ""
+  }
 
   ## Need to write to a temp file first, to preserve absense of trailing ws
   tmp <- tempfile()
@@ -720,12 +764,12 @@ idesc_write <- function(self, private, file) {
   removed <- ! names(private$notws) %in% colnames(mat)
   if (any(removed)) private$notws <- private$notws[! removed]
 
-  changed <- mat[, names(private$notws)] != private$notws
-  if (any(changed)) private$notws <- private$notws[! changed]
-
   postprocess_trailing_ws(tmp, names(private$notws))
   if (file.exists(file) && is_dir(file)) file <- find_description(file)
-  writeLines(readLines(tmp), file)
+
+  ofile <- file(file, encoding = encoding, open = "w+")
+  on.exit(close(ofile), add = TRUE)
+  writeLines(readLines(tmp), ofile)
 
   invisible(self)
 }
@@ -751,11 +795,19 @@ idesc_get <- function(self, private, keys) {
   assert_that(is.character(keys), has_no_na(keys))
   res <- lapply(private$data[keys], "[[", "value")
   res[vapply(res, is.null, logical(1))] <- NA_character_
-  res <- unlist(res)
+  res <- as.character(unlist(res))
   names(res) <- keys
   res
 }
 
+idesc_get_field <- function(self, private, key, default, trim_ws) {
+  assert_that(is_string(key))
+  assert_that(is_flag(trim_ws))
+  val <- private$data[[key]]$value
+  if (trim_ws && !is.null(val)) val <- str_trim(val)
+  val %||% default
+}
+
 idesc_get_or_fail <- function(self, private, keys) {
   assert_that(is.character(keys), has_no_na(keys))
   res <- self$get(keys)
@@ -792,7 +844,7 @@ idesc_set <- function(self, private, ...) {
     stop("$set needs two unnamed args, or all named args, see docs")
   }
 
-  fields <- create_fields(keys, values)
+  fields <- create_fields(keys, enc2utf8(values))
   lapply(fields, check_field, warn = TRUE)
   check_encoding(self, private, lapply(fields, "[[", "value"))
   private$data[keys] <- fields
